@@ -1,4 +1,7 @@
-__version__ = "3.0"
+import os.path as op
+from os import scandir
+
+__version__ = "4.0.0"
 __author__ = "Pablo Velasco"
 __author_email__ = "pablo.velasco@nyu.edu"
 __url__ = "https://github.com/cbinyu/bidsphysio"
@@ -19,12 +22,20 @@ CLASSIFIERS = [
 
 PYTHON_REQUIRES = ">=3.6"
 
-REQUIRES = [
-    'numpy >= 1.17.1',
-    'pydicom >= 1.4.1',
-    'bioread >= 1.0.4',
-    'etelemetry',
-]
+
+def find_subpackages():
+    thispath = op.dirname(__file__) or '.'
+
+    # find_packages() doesn't find the bidsphysio.* sub-packages
+    # because they don't have an __init__.py file.
+    children_dirs = [
+        op.relpath(f.path, thispath) for f in scandir(thispath)
+        if f.is_dir()
+    ]
+    return [d for d in children_dirs if d.startswith('bidsphysio.')]
+
+
+REQUIRES = find_subpackages()
 
 TESTS_REQUIRES = [
     'pytest'
